function discs=PA2SCCModel(x)
%  Constrained model with variable capital utilization, unemployment, and constrained
%  consumers

global kstart dstart fks fds nu gammaq omegas ss firstObs lastObs sigma alpha beta deltak deltad kappak kappad phi nBar T IfSave kstar dstar 

discs=zeros(5*T-8,1);  

%Core: pd ct k d r 
Loc=1;
var=1;
Lens=lastObs-firstObs;
pds=[0;x(Loc:Loc+Lens(var))];  %  pd
Loc=Loc+Lens(var)+1;
var=var+1;
cts=[0;x(Loc:Loc+Lens(var))];  %  c
Loc=Loc+Lens(var)+1;
var=var+1;
ks=[kstart;x(Loc:Loc+Lens(var));kstar]; % k
Loc=Loc+Lens(var)+1;
var=var+1;
ds=[dstart;x(Loc:Loc+Lens(var));dstar]; % d
Loc=Loc+Lens(var)+1;
var=var+1;
rs=[0;x(Loc:Loc+Lens(var));0];  % rs(T) is undefined
ys=zeros(T,1);
pks=zeros(T,1);
pcs=zeros(T,1);
mus=zeros(T,1);
cbs=zeros(T,1);
cys=zeros(T,1);
qks=zeros(T,1);
qds=zeros(T,1);
invks=zeros(T,1);
invds=zeros(T,1);
ms=zeros(T,1);

%  Auxiliary variables

% Employment, 2:T
ns(2:T,1)=nBar;
%  Capacity utilization, 2:T
xs(2:T,1)=1;
%  Output, 2:T
ys(2:T)=ns(2:T).^alpha.*(xs(2:T).*ks(1:T-1)).^(1-alpha);
%  Rental price of capital, 2:T
pks(2:T)=(1-alpha).*(xs(2:T).*ks(1:T-1)./ns(2:T)).^(-alpha);
%  Price of total consumption, 2:T
pcs(2:T)=phi^(-phi)*(1-phi)^(-(1-phi)).*pds(2:T).^(1-phi);
% Discounter, 2:T-1
mucN=cts(2:T-1).^(-1/sigma);
mucF=cts(3:T).^(-1/sigma);
mus(2:T-1,1)=beta*mucF./mucN;
%  Constrained total consumption, 2:T
cbs(2:T)=(omegas(2:T)-ss(2:T)).*ys(2:T)./pcs(2:T);
%  Goods consumption, 2:T
cys(2:T)=phi*pcs(2:T).*(cts(2:T)+cbs(2:T));
%  Tobin's q for capital, 2:T
qks(2:T)=kappak*(ks(2:T)-ks(1:T-1))./ks(1:T-1) +1;
%  Tobin's q for housing, 2:T
qds(2:T)=kappad*(ds(2:T)-ds(1:T-1))./ds(1:T-1) +1;

%  Discrepancies

iDisc=1;
iTop=T-1;
% Material balance, 2:T
invks(2:T)=ks(2:T)-(1-deltak)*ks(1:T-1)+kappak*(ks(2:T)-ks(1:T-1)).^2./(2*ks(1:T-1));
invds(2:T)=ds(2:T)-(1-deltad)*ds(1:T-1)+kappad*(ds(2:T)-ds(1:T-1)).^2./(2*ds(1:T-1));
discs(iDisc:iTop)=ys(2:T)-cys(2:T)-invks(2:T)-invds(2:T)-gammaq*nu*ns(2:T);
%  Euler, 2:T-1
iDisc=iTop+1;
iTop=iDisc+T-3;
discs(iDisc:iTop)=(1+rs(2:T-1)).*mus(2:T-1)-1;
%  Rental prices, 3:T
iDisc=iTop+1;
iTop=iDisc+T-3;
discs(iDisc:iTop)=pks(3:T)-((1+rs(2:T-1)).*(1+fks(2:T-1)).*qks(2:T-1)-(1-deltak)*qks(3:T));
iDisc=iTop+1;
iTop=iDisc+T-3;
discs(iDisc:iTop)=pds(3:T)-((1+rs(2:T-1)).*(1+fds(2:T-1)).*qds(2:T-1)-(1-deltad)*qds(3:T));
% Housing, 2:T
iDisc=iTop+1;
iTop=iDisc+T-2;
discs(iDisc:iTop)=pds(2:T).*xs(2:T).*ds(1:T-1)-(1-phi)*pcs(2:T).*(cts(2:T)+cbs(2:T));

if ~IfSave
    return
end

save PA2SCCModel
AllVars=[pds,cts,ks,ds,rs,ys,pks,pcs,mus,cbs,cys,qks,qds,invks,invds,ms,ss,omegas,fks];
save PA2SCCModel AllVars
