clc
clear all

MainFileName='Results2SZCC ';
TrajTab='ZLB trajectories';
TermVals=[];
global  gs gStart pis fks fds psi nu gammaq dElev omegas ss lastObs firstObs sigma alpha beta deltak deltad kappak kappad phi nBar T IfSave kstar dstar AllStats

MaxFunEvals=50000;
MaxIter=50;
options=optimset('Display','iter','MaxFunEvals',MaxFunEvals,'MaxIter',MaxIter,'Algorithm','levenberg-marquardt','TolFun',.00000000001,'TolX',.000000001);
deltak=0.0188;
deltad=0.0129;
alpha=0.646;
r=0.000291584;
rStar=r;
beta=1/(1+rStar);
nBar=.945;
sigma=0.5;
nu=0.12;
gammaq=0.14;
kappak=8;   
kappad=8;
phi=0.82;
psi=1/(1-alpha);  
pi=-r;

%  Parameters that can be set separately:
%  kappak, kappad: adjustment costs
%  phi: budget share for non-durables
%  omega: fraction constrained consumption
%  sBar: Fraction of total amount of s=0.07 to include in calcs
%  dElev: Initial elevation of durables stock from stat
%  psi:  Elasticity of employment
%  FB: foreign borrowing
%  fshock: Financial fricion shock
%  rho: persistence of credit tightening and financial friction

rhof=0.8;
rhos=0.98;
rhog=0.95;
omegaOn=0.513;
sBarOn=1;
dElevOn=0.14;
fShockOn=0.005;
gStart=0;

CaseNames={'Null','dElev','CC','FF','all 3','CC+dElev'};
%-------------------1-------2-----3-----4-----5--------6
for icase=[5,6,3]
    omega=0;
    sBar=0;
    dElev=0;
    fShock=0;
    T=17;
    if strcmp(CaseNames{icase},'dElev')
        dElev=dElevOn;  
        kappad=22;
        omega=omegaOn;
    end
    if strcmp(CaseNames{icase},'CC')
        sBar=sBarOn;
        omega=omegaOn;
    end
    if strcmp(CaseNames{icase},'FF')
        fShock=fShockOn;
    end
    if strcmp(CaseNames{icase},'all 3')
        sBar=sBarOn;
        omega=omegaOn;
        dElev=dElevOn;
        fShock=fShockOn;
    end
    if strcmp(CaseNames{icase},'CC+dElev')
        sBar=sBarOn;
        omega=omegaOn;
        dElev=dElevOn;
    end
    
    %  Static solution
    
    %      y k d c pc
    
    pk=rStar+deltak;
    k=nBar*((1-alpha)/pk)^(1/alpha);
    y=nBar^alpha*k^(1-alpha);
    x=[y;k;k;.5;1];
    discs=StatModel(x);
    MaxFunEvals=50000;
    MaxIter=500;
    options=optimset('Display','iter','MaxFunEvals',MaxFunEvals,'MaxIter',MaxIter,'Algorithm','levenberg-marquardt','TolFun',.00000000001,'TolX',.000000001);
    xNew=fsolve(@StatModel,x,options);
    % xNew=y k d c pc
    resNew=StatModel(xNew);
    kstar=xNew(2);
    dstar=xNew(3);
    cons=xNew(4);
    
    %  Dynamic solution
    
    ResultsFile=[MainFileName CaseNames{icase} ' .xlsx'];
    xOvers=[];
    pd=rStar+deltad;
    % Core: pd    ct     n     k     d
    xStarts=[pd;xNew(4)*(1-sBar*omega);nBar;kstar;dstar];
    Nvar=numel(xStarts);
    firstObs(1:5)=2;  %  pd, ct, n, k, d
    lastObs=[T,T-1,T,T,T];
    loc=1;
    for var=1:Nvar
        for t=firstObs(var):lastObs(var)
            x(loc)=xStarts(var);
            loc=loc+1;
        end
    end
    
    %  Exogenous variables
    
     pis(1:T,1)=pi;
    fks=zeros(T,1);
    gs=zeros(T,1);
    ss=zeros(T,1);
    ss(2)=sBar*.067;
    gs(2)=gStart;
    fks(2)=fShock;
    for t=2:T-1
        fks(t+1)=fks(t)*rhof;
        ss(t+1)=ss(t)*rhos;
        gs(t+1)=gs(t)*rhog;
    end
    omegas(1:T,1)=omega;
    fds=fks;
    
    % Checks
    
    IfSave=true;
    discs=PA2SZCCModel(x);
    load PA2SZCCModel AllVars
    AllVars1=AllVars;
    
    %  Solve
    
    MaxFunEvals=30000;
    MaxIter=200;
    IfSave=false;
    options=optimset('Display','iter','MaxFunEvals',MaxFunEvals,'MaxIter',MaxIter,'Algorithm','levenberg-marquardt','TolFun',.00000000000001,'TolX',.000000000001);
    xN=fsolve(@PA2SZCCModel,x,options);
    
    %  Extract variables
    
    IfSave=true;
    Check=PA2SZCCModel(xN);
    IfSave=false;
    load PA2SZCCModel AllVars
    ns=AllVars(:,3);
    ks=AllVars(:,4);
    ds=AllVars(:,5);
    rs=AllVars(:,6);
    
    %  Calculate full-employment interest rate (multiplied by 400)
    
    rFuncCoeffs=[-0.042219,-0.077363,-281.461300,-6.638409,0.000472,-0.212012,0.012055,-0.522350,0.023711,59.463750,5.295293;
    -0.044185,-0.080123,-372.414700,-9.728025,0.000556,-0.005050,0.023986,-0.111388,0.043877,39.153750,5.277406];
    
    for t=1:T
        vals=[ks(t),ds(t),fks(t),ss(t),ks(t)*ds(t),ks(t)*fks(t),ks(t)*ss(t),ds(t)*fks(t),ds(t)*ss(t),fks(t)*ss(t),1];
        omegaCase=(omegas(t)>0)+1;
        rfs(t,1)=(1/400)*vals*rFuncCoeffs(omegaCase,:)';
    end
    
    %  Save results for case and pi
    
    xlswriteX(ResultsFile,[AllVars,rfs],TrajTab,'B4');
    xlswriteX(ResultsFile,[deltak,deltad,kappak,kappad,alpha,T,beta,r,nBar,sigma,nu,gammaq,phi,rhof,rhos,rhog,psi,pi],'params','c5');
    xlswriteX(ResultsFile,AllStats,'params','c7');
    xlswriteX(ResultsFile,Check,'Discs','c3');
    
    %  Save terminal values to calculate non-ZLB periods
    
    TermVals=[TermVals;[ks(T),ds(T),fks(T),omegas(T),ss(T)]];
end % icase

xlswriteX('Paths.xlsx',TermVals,'Term values','b3');

